##############################################################
### STAR*D data, IDS-C 30 and HAMD17 symptoms, weeks 0, 12 ###
##############################################################

library(qgraph)
library(ggplot2)
library(psych)


setwd("C:/Users/u0097060/Dropbox/Research/My Papers/1. First author publications/MI paper/analyses/R")


##### DATA PREPARATION

data<-read.csv("IDS_HAMD.csv", head=T)
data[data == -999] <- NA

# careful, there are some IDS items in between we don't want to select, like averaged sleep, or 9A and 9B that are mostly missing
# variables are defined in document "STAR*D List of Variables and Attributes for Form RA". careful, order is different in "STAR*D ROA questionnaire" document.

data <- subset(data, select=c(age,sex,DATE.1,DATE.2,Hsum.1,Hsum.2,IDS_sum.1,IDS_sum.2,IDS01.1:IDS03.1, IDS04.1:IDS09.1,IDS10.1, IDS1112.1, IDS1314.1,IDS15.1:IDS30.1, IDS01.2:IDS03.2, IDS04.2:IDS09.2,IDS10.2, IDS1112.2, IDS1314.2,IDS15.2:IDS30.2, H1.1:H17.1, H1.2:H17.2))
data <-na.omit(data)

data.I.0 <- subset(data, select=c(IDS01.1:IDS03.1, IDS04.1:IDS09.1,IDS10.1, IDS1112.1, IDS1314.1,IDS15.1:IDS30.1))
data.I.12 <- subset(data, select=c(IDS01.2:IDS03.2, IDS04.2:IDS09.2,IDS10.2, IDS1112.2, IDS1314.2,IDS15.2:IDS30.2))
data.H.0 <- subset(data, select=c(H1.1:H17.1))
data.H.12 <- subset(data, select=c(H1.2:H17.2))

s.i=c("I01","I02","I03","I04","I05", "I06","I07","I08","I09","I10", "I11","I12", "I13","I14","I15","I16","I17","I18","I19","I20","I21","I22","I23","I24","I25","I26","I27","I28")
s.h=c("H01","H02","H03","H04","H05", "H06","H07","H08","H09","H10", "H11","H12", "H13","H14","H15", "H16","H17")

##### DESCRIPTIVE STATISTICS, n=2522

mean(data$age) # 42.00
sd(data$age) # 13.19
mean(data$sex) # 1.635
mean(data$DATE.1/7) # 0.13
sd(data$DATE.1/7) #  0.14
mean(data$DATE.2)/7 # 11.05
sd(data$DATE.2/7) # 3.62
mean(data$Hsum.1) # 19.68
sd(data$Hsum.1) # 6.40
mean(data$Hsum.2) # 11.51
sd(data$Hsum.2) # 8.44
mean(data$IDS_sum.1) # 35.50
sd(data$IDS_sum.1) # 11.32
mean(data$IDS_sum.2) # 20.60
sd(data$IDS_sum.2) # 15.26

data.sums<-subset(data, select=c(Hsum.1,Hsum.2,IDS_sum.1,IDS_sum.2))
cor(data.sums$Hsum.1, data.sums$IDS_sum.1) #0.8844463
cor(data.sums$Hsum.2, data.sums$IDS_sum.2) #0.9571081

### mean sd of all symptoms at baseline. IDS t0=1.004504; t11=0.960008; HAMD t0=0.8335235; t11=.0.8252407
(sd(data.I.0[[1]])+  sd(data.I.0[[2]])+  sd(data.I.0[[3]])+  sd(data.I.0[[4]])+  sd(data.I.0[[5]])+  sd(data.I.0[[6]])+  sd(data.I.0[[7]])+  sd(data.I.0[[8]])+  sd(data.I.0[[9]])+  sd(data.I.0[[10]])+  sd(data.I.0[[11]])+  sd(data.I.0[[12]])+  sd(data.I.0[[13]])+  sd(data.I.0[[14]])+  sd(data.I.0[[15]])+  sd(data.I.0[[16]])+  sd(data.I.0[[17]])+  sd(data.I.0[[18]])+  sd(data.I.0[[19]])+  sd(data.I.0[[20]])+  sd(data.I.0[[21]])+  sd(data.I.0[[22]])+  sd(data.I.0[[23]])+  sd(data.I.0[[24]])+  sd(data.I.0[[25]])+  sd(data.I.0[[26]])+  sd(data.I.0[[27]])+  sd(data.I.0[[28]]))/28
(sd(data.I.12[[1]])+   sd(data.I.12[[2]])+   sd(data.I.12[[3]])+   sd(data.I.12[[4]])+   sd(data.I.12[[5]])+   sd(data.I.12[[6]])+   sd(data.I.12[[7]])+   sd(data.I.12[[8]])+   sd(data.I.12[[9]])+   sd(data.I.12[[10]])+   sd(data.I.12[[11]])+   sd(data.I.12[[12]])+   sd(data.I.12[[13]])+   sd(data.I.12[[14]])+   sd(data.I.12[[15]])+   sd(data.I.12[[16]])+   sd(data.I.12[[17]])+   sd(data.I.12[[18]])+   sd(data.I.12[[19]])+   sd(data.I.12[[20]])+   sd(data.I.12[[21]])+   sd(data.I.12[[22]])+   sd(data.I.12[[23]])+   sd(data.I.12[[24]])+   sd(data.I.12[[25]])+   sd(data.I.12[[26]])+   sd(data.I.12[[27]])+   sd(data.I.12[[28]]))/28
(sd(data.H.0[[1]])+  sd(data.H.0[[2]])+  sd(data.H.0[[3]])+  sd(data.H.0[[4]])+  sd(data.H.0[[5]])+  sd(data.H.0[[6]])+  sd(data.H.0[[7]])+  sd(data.H.0[[8]])+  sd(data.H.0[[9]])+  sd(data.H.0[[10]])+  sd(data.H.0[[11]])+  sd(data.H.0[[12]])+  sd(data.H.0[[13]])+  sd(data.H.0[[14]])+  sd(data.H.0[[15]])+  sd(data.H.0[[16]])+  sd(data.H.0[[17]]))/17
(sd(data.H.12[[1]])+  sd(data.H.12[[2]])+  sd(data.H.12[[3]])+  sd(data.H.12[[4]])+  sd(data.H.12[[5]])+  sd(data.H.12[[6]])+  sd(data.H.12[[7]])+  sd(data.H.12[[8]])+  sd(data.H.12[[9]])+  sd(data.H.12[[10]])+  sd(data.H.12[[11]])+  sd(data.H.12[[12]])+  sd(data.H.12[[13]])+  sd(data.H.12[[14]])+  sd(data.H.12[[15]])+  sd(data.H.12[[16]])+  sd(data.H.12[[17]]))/17

### significant increase in sum score / SD from 0 to 6?
t.test(data$Hsum.1, data$Hsum.2, paired=T) #t = 51.30, df = 2521, p < 2.2e-16
t.test(data$IDS_sum.1, data$IDS_sum.2, paired=T) #t = 51.87, df = 2521, p-value < 2.2e-16


##### HISTOGRAMS
IDS_sum.1=data$IDS_sum.1
IDS_sum.2=data$IDS_sum.2
IDS_sum.1=as.data.frame(IDS_sum.1)
IDS_sum.2=as.data.frame(IDS_sum.2)
Hsum.1=data$Hsum.1
Hsum.2=data$Hsum.2
Hsum.1=as.data.frame(Hsum.1)
Hsum.2=as.data.frame(Hsum.2)
names(IDS_sum.1)[names(IDS_sum.1)=="IDS_sum.1"] <- "length"
names(IDS_sum.2)[names(IDS_sum.2)=="IDS_sum.2"] <- "length"
IDS_sum.1$time <- 'baseline'
IDS_sum.2$time <- 'week 11'
IDS.plot <- rbind(IDS_sum.1,IDS_sum.2)
names(Hsum.1)[names(Hsum.1)=="Hsum.1"] <- "length"
names(Hsum.2)[names(Hsum.2)=="Hsum.2"] <- "length"
Hsum.1$time <- 'baseline'
Hsum.2$time <- 'week 11'
H.plot <- rbind(Hsum.1,Hsum.2)

pdf("IDS_C_density.pdf")
ggplot(IDS.plot, aes(length, fill = time)) + geom_density(alpha = 0.2)+ theme_bw() +
  xlab("IDS-C") + ylab("Density") 
dev.off()

pdf("H_density.pdf")
ggplot(H.plot, aes(length, fill = time)) + geom_density(alpha = 0.2)+ theme_bw() +
  xlab("H") + ylab("Density") 
dev.off()


##### PARALLEL ANALYSIS & SCREE PLOTS
t0.I <- cor_auto(data.I.0)
t12.I <- cor_auto(data.I.12)
t0.H <- cor_auto(data.H.0)
t12.H <- cor_auto(data.H.12)

### conduct parallel analysis to receive PA control eigenvalues

load(file = "PA.t0.I.Rdata")
# PA.t0.I = fa.parallel(data.I.0, fm="wls", n.iter=50, quant=.95, cor="poly", fa="pc") # extract 6 components
# save(PA.t0.I, file = "PA.t0.I-C.Rdata")
# eigen(t0.I)$values        #EV of data from eigen function
# PA.t0.I$pc.values         #equal results of data from fa.parallel analysis; also equals mplus EFA results
# describe(PA.t0.I$values)  #the first 10 entries of the column "mean" are the ones we need to plot results of the PA.

load(file = "PA.t12.I.Rdata")
# PA.t12.I = fa.parallel(data.I.12, fm="wls", n.iter=50, quant=.95, cor="poly", fa="pc") # extract 3 components
# save(PA.t12.I, file = "PA.t12.I-C.Rdata")

load(file = "PA.t0.H.Rdata")
# PA.t0.H = fa.parallel(data.H.0, fm="wls", n.iter=50, quant=.95, cor="poly", fa="pc") # extract 4 components
# save(PA.t0.H, file = "PA.t0.H.Rdata")
# eigen(t0.H)$values      #EV of data from eigen function
# PA.t0.H$pc.values       #equal results of data from fa.parallel analysis; also equals mplus EFA results
# PA.t0.H$pc.sim          #simulated EV
# describe(PA.t0.H$values)

load(file = "PA.t12.H.Rdata")
# PA.t12.H = fa.parallel(data.H.12, fm="wls", n.iter=50, quant=.95, cor="poly", fa="pc") # extract 3 components
# save(PA.t12.H, file = "PA.t12.H.Rdata")


### extract eigenvalues from data
eigen.I <- rbind(
  data.frame(t = 0,x = 1:ncol(t0.I),
    eigen = eigen(t0.I)$values),
  data.frame(t = 11,x = 1:ncol(t12.I),
    eigen = eigen(t12.I)$values))

eigen.H <- rbind(
  data.frame(t = 0,x = 1:ncol(t0.H),
    eigen = eigen(t0.H)$values),  
  data.frame(t = 11,x = 1:ncol(t12.H),
    eigen = eigen(t12.H)$values))


### PLOT parallel analysis 
eigen.I2 <- eigen.I
t <- c("PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA")
x <- 1:28
#results from fa.parallel simulated eigenvalues (I enter them here manually, from 'mean' column in "describe(PA.t0.I$values)"
eigen <- c(1.25,1.22,1.19,1.16,1.14,1.12,1.11,1.09,1.06,1.05,0.3,0.2,0.2,0.2,0.2,0.2,0.2,0.2,0.2,0.2,0.2,0.2,0.2,0.2,0.2,0.2,0.2,0.2)
df.I <- data.frame(t,x,eigen)
eigen.I2 <- rbind(eigen.I2, df.I)

eigen.H2 <- eigen.H
t <- c("PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA","PA")
x <- 1:17
#R psych fa.parallel.poly PA simulated eigenvalues
eigen <- c(1.28,1.17,1.13,1.10,1.08,1.06,1.04,1.02,1.02,1.02,0.2,0.2,0.2,0.2,0.2,0.2,0.2)
df.H <- data.frame(t,x,eigen)
eigen.H2 <- rbind(eigen.H2, df.H)


g.I2color <- ggplot(eigen.I2, aes(x = x, y = eigen, colour = factor(t))) + 
  geom_line() + geom_point(size=3) + theme_bw() + theme(legend.title=element_blank()) +
  scale_x_continuous(limits = c(1, 7), breaks = 1:7) +
  scale_y_continuous(limits = c(0, 13), breaks = c(0,2,4,6,8,10,12)) +
  xlab("Factors") +
  ylab("Eigenvalues") + 
  ggtitle("IDS-C Eigenvalues at weeks 0 and 11")
g.I2bw <- ggplot(eigen.I2, aes(x = x, y = eigen, shape = t)) + 
  geom_line() + geom_point(size=3) + theme_bw() + theme(legend.title=element_blank()) +
  scale_x_continuous(limits = c(1, 7), breaks = 1:7) +
  scale_y_continuous(limits = c(0, 13), breaks = c(0,2,4,6,8,10,12)) +
  xlab("Factors") +
  ylab("Eigenvalues") + 
  ggtitle("IDS-C Eigenvalues at weeks 0 and 11")

g.H2color <- ggplot(eigen.H2, aes(x = x, y = eigen, colour = factor(t))) + 
  geom_line() + geom_point(size=3) + theme_bw() + theme(legend.title=element_blank()) +
  scale_x_continuous(limits = c(1, 7), breaks = 1:7) +
  scale_y_continuous(limits = c(0, 8), breaks = c(0:8)) +
  xlab("Factors") +
  ylab("Eigenvalues") + 
  ggtitle("HRSD Eigenvalues at weeks 0 and 11")
g.H2bw <- ggplot(eigen.H2, aes(x = x, y = eigen, shape = t)) + 
  geom_line() + geom_point(size=3) + theme_bw() + theme(legend.title=element_blank()) +
  scale_x_continuous(limits = c(1, 7), breaks = 1:7) +
  scale_y_continuous(limits = c(0, 8), breaks = c(0:8)) +
  xlab("Factors") +
  ylab("Eigenvalues") + 
  ggtitle("HRSD Eigenvalues at weeks 0 and 11")

ggsave(plot=g.I2color,height=5,width=7, filename="eigenvalues_IDS_color.pdf", useDingbats=FALSE)
ggsave(plot=g.H2color,height=5, width=7, filename="eigenvalues_HAMD_color.pdf", useDingbats=FALSE)
 
ggsave(plot=g.I2bw,height=5,width=7, filename="eigenvalues_IDS_bw.pdf", useDingbats=FALSE)
ggsave(plot=g.H2bw,height=5,width=7, filename="eigenvalues_HAMD_bw.pdf", useDingbats=FALSE)


##### INCREASING CORRELATIONS AND ALPHA

# matrix sum without diagonal
mean(t0.I[upper.tri(t0.I)])
mean(t12.I[upper.tri(t12.I)])
mean(t0.H[upper.tri(t0.H)])
mean(t12.H[upper.tri(t12.H)])

# alpha
alpha(t0.I)
alpha(t12.I)
alpha(t0.H)
alpha(t12.H)

# intercorrelation increases over time 
dev.off()
pdf("NW_IDS_HAMD.pdf")
H.t0<-qgraph(t0.H, title="Polychoric correlations HAM-D 17 week 0", max=.9, cut=.5, min=.3)
H.t12<-qgraph(t12.H, title="Polychoric correlations HAM-D 17 week 11", max=.9, cut=.5, min=.3)
H.t0<-qgraph(t0.I, title="Polychoric correlations IDS 30 week 0", max=.9, cut=.5, min=.3)
H.t12<-qgraph(t12.I, title="Polychoric correlations IDS 30 week 11", max=.9, cut=.5, min=.3)
dev.off()
